@@ -11,13 +11,62 @@ __all__ = [
     "JSTemplateTagTest",
     "RawTemplateTagTest",
     "ICHTemplateTagTest",
+    "DustTemplateTagTest",
 ]
 
 
 DIR = os.path.join(os.path.dirname(__file__), "templates")
 
 
-class JSTemplateTagTest(TestCase):
+class BaseMustacheJSTagTestMixin (object):
+    # The following should be true for all tag types.  Remember to define
+    # tag_string for any derived test classes.
+
+    @override_settings(MUSTACHEJS_DIRS=[DIR], DEBUG=False)
+    def test_no_template(self):
+        res = Template(
+            "{{% load mustachejs %}}{{% {} 'notemplate' %}}".format(self.tag_string)
+            ).render(Context())
+
+        self.assertEqual(res, "")
+
+
+    @override_settings(MUSTACHEJS_DIRS=[DIR], DEBUG=True)
+    def test_no_template_debug(self):
+        from mustachejs.loading import MustacheJSTemplateNotFound
+        with self.assertRaises(MustacheJSTemplateNotFound):
+            Template(
+                "{{% load mustachejs %}}{{% {} 'notemplate' %}}".format(self.tag_string)
+                ).render(Context())
+
+
+    @override_settings(MUSTACHEJS_DIRS=[DIR])
+    def test_no_break_out(self):
+        res = Template(
+                "{{% load mustachejs %}}{{% {} '../outside_dir' %}}".format(self.tag_string)
+                ).render(Context())
+
+        self.assertEqual(res, "")
+
+
+    @override_settings(MUSTACHEJS_DIRS=[DIR])
+    def test_no_absolute(self):
+        res = Template(
+                "{{% load mustachejs %}}{{% {} '/testtemplate' %}}".format(self.tag_string)
+                ).render(Context())
+
+        self.assertEqual(res, "")
+
+
+    def test_bad_args(self):
+        with self.assertRaises(TemplateSyntaxError):
+            Template(
+                "{{% load mustachejs %}}{{% {} %}}".format(self.tag_string)
+                ).render(Context())
+
+class JSTemplateTagTest(TestCase, BaseMustacheJSTagTestMixin):
+    tag_string = 'mustachejs'
+
     @override_settings(MUSTACHEJS_DIRS=[DIR])
     def test_simple(self):
         res = Template(
@@ -46,50 +95,11 @@ class JSTemplateTagTest(TestCase):
              "</script>")
 
 
-    @override_settings(MUSTACHEJS_DIRS=[DIR], DEBUG=False)
-    def test_no_template(self):
-        res = Template(
-            "{% load mustachejs %}{% mustachejs 'notemplate' %}"
-            ).render(Context())
-
-        self.assertEqual(res, "")
 
 
-    @override_settings(MUSTACHEJS_DIRS=[DIR], DEBUG=True)
-    def test_no_template_debug(self):
-        from mustachejs.loading import MustacheJSTemplateNotFound
-        with self.assertRaises(MustacheJSTemplateNotFound):
-            Template(
-                "{% load mustachejs %}{% mustachejs 'notemplate' %}"
-                ).render(Context())
+class ICHTemplateTagTest(TestCase, BaseMustacheJSTagTestMixin):
+    tag_string = 'mustacheich'
 
-
-    @override_settings(MUSTACHEJS_DIRS=[DIR])
-    def test_no_break_out(self):
-        res = Template(
-                "{% load mustachejs %}{% mustachejs '../outside_dir' %}"
-                ).render(Context())
-
-        self.assertEqual(res, "")
-
-
-    @override_settings(MUSTACHEJS_DIRS=[DIR])
-    def test_no_absolute(self):
-        res = Template(
-                "{% load mustachejs %}{% mustachejs '/testtemplate' %}"
-                ).render(Context())
-
-        self.assertEqual(res, "")
-
-
-    def test_bad_args(self):
-        with self.assertRaises(TemplateSyntaxError):
-            Template(
-                "{% load mustachejs %}{% mustachejs %}"
-                ).render(Context())
-
-
-class ICHTemplateTagTest(TestCase):
     @override_settings(MUSTACHEJS_DIRS=[DIR])
     def test_simple(self):
         res = Template(
@@ -116,50 +126,44 @@ class ICHTemplateTagTest(TestCase):
              '</script>')
 
 
-    @override_settings(MUSTACHEJS_DIRS=[DIR], DEBUG=False)
-    def test_no_template(self):
+class DustTemplateTagTest(TestCase, BaseMustacheJSTagTestMixin):
+    tag_string = 'dustjs'
+
+    @override_settings(MUSTACHEJS_DIRS=[DIR])
+    def test_simple(self):
         res = Template(
-            "{% load mustachejs %}{% mustacheich 'notemplate' %}"
+            "{% load mustachejs %}{% dustjs 'testtemplate' %}"
             ).render(Context())
 
-        self.assertEqual(res, "")
-
-
-    @override_settings(MUSTACHEJS_DIRS=[DIR], DEBUG=True)
-    def test_no_template_debug(self):
-        from mustachejs.loading import MustacheJSTemplateNotFound
-        with self.assertRaises(MustacheJSTemplateNotFound):
-            Template(
-                "{% load mustachejs %}{% mustachejs 'notemplate' %}"
-                ).render(Context())
+        self.assertEqual(
+            res,
+            '<script type="text/javascript">'
+            "if (typeof(dust) !== 'undefined') {"
+                "compiled = dust.compile('<p>Mustache\\'s template full of {{ foo }} and \\\\.</p>\\n', 'testtemplate');"
+                "dust.loadSource(compiled);"
+            "}"
+            '</script>')
 
 
     @override_settings(MUSTACHEJS_DIRS=[DIR])
-    def test_no_break_out(self):
+    def test_variable_template_name(self):
         res = Template(
-                "{% load mustachejs %}{% mustachejs '../outside_dir' %}"
-                ).render(Context())
+            "{% load mustachejs %}{% dustjs templatename %}").render(
+            Context({"templatename": "testtemplate"}))
 
-        self.assertEqual(res, "")
+        self.assertEqual(
+            res,
+            '<script type="text/javascript">'
+            "if (typeof(dust) !== 'undefined') {"
+                "compiled = dust.compile('<p>Mustache\\'s template full of {{ foo }} and \\\\.</p>\\n', 'testtemplate');"
+                "dust.loadSource(compiled);"
+            "}"
+            '</script>')
 
 
-    @override_settings(MUSTACHEJS_DIRS=[DIR])
-    def test_no_absolute(self):
-        res = Template(
-                "{% load mustachejs %}{% mustachejs '/testtemplate' %}"
-                ).render(Context())
+class RawTemplateTagTest(TestCase, BaseMustacheJSTagTestMixin):
+    tag_string = 'mustacheraw'
 
-        self.assertEqual(res, "")
-
-
-    def test_bad_args(self):
-        with self.assertRaises(TemplateSyntaxError):
-            Template(
-                "{% load mustachejs %}{% mustachejs %}"
-                ).render(Context())
-
-
-class RawTemplateTagTest(TestCase):
     @override_settings(MUSTACHEJS_DIRS=[DIR])
     def test_simple(self):
         res = Template(
@@ -180,46 +184,3 @@ class RawTemplateTagTest(TestCase):
         self.assertEqual(
             res,
             "<p>Mustache's template full of {{ foo }} and \\.</p>\n")
-
-
-    @override_settings(MUSTACHEJS_DIRS=[DIR], DEBUG=False)
-    def test_no_template(self):
-        res = Template(
-            "{% load mustachejs %}{% mustacheraw 'notemplate' %}"
-            ).render(Context())
-
-        self.assertEqual(res, "")
-
-
-    @override_settings(MUSTACHEJS_DIRS=[DIR], DEBUG=True)
-    def test_no_template_debug(self):
-        from mustachejs.loading import MustacheJSTemplateNotFound
-        with self.assertRaises(MustacheJSTemplateNotFound):
-            Template(
-                "{% load mustachejs %}{% mustacheraw 'notemplate' %}"
-                ).render(Context())
-
-
-    @override_settings(MUSTACHEJS_DIRS=[DIR])
-    def test_no_break_out(self):
-        res = Template(
-                "{% load mustachejs %}{% mustacheraw '../outside_dir' %}"
-                ).render(Context())
-
-        self.assertEqual(res, "")
-
-
-    @override_settings(MUSTACHEJS_DIRS=[DIR])
-    def test_no_absolute(self):
-        res = Template(
-                "{% load mustachejs %}{% mustacheraw '/testtemplate' %}"
-                ).render(Context())
-
-        self.assertEqual(res, "")
-
-
-    def test_bad_args(self):
-        with self.assertRaises(TemplateSyntaxError):
-            Template(
-                "{% load mustachejs %}{% mustacheraw %}"
-                ).render(Context())
